@@ -1,15 +1,16 @@
 package Perinci::To::HTML;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 use Moo;
 
 use Locale::TextDomain::UTF8 'Perinci-To-HTML';
 
 extends 'Perinci::To::PackageBase';
 
-our $VERSION = '0.02'; # VERSION
-
 has heading_level => (is => 'rw', default=>sub{1});
 
 sub BUILD {
@@ -212,7 +213,7 @@ Perinci::To::HTML - Generate HTML documentation from Rinci package metadata
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::To::HTML (from Perl distribution Perinci-To-HTML), released on 2014-05-02.
+This document describes version 0.03 of Perinci::To::HTML (from Perl distribution Perinci-To-HTML), released on 2015-08-18.
 
 =head1 DESCRIPTION
 
@@ -226,7 +227,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-HTML>.
 
 =head1 BUGS
 
@@ -238,11 +239,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
